@@ -8,6 +8,8 @@ from sphinx_click import ext
 class CommandTestCase(unittest.TestCase):
     """Validate basic ``click.Command`` instances."""
 
+    maxDiff = None
+
     def test_no_parameters(self):
         """Validate a `click.Command` with no parameters.
 
@@ -52,6 +54,12 @@ class CommandTestCase(unittest.TestCase):
             help='A sample option with choices',
             type=click.Choice(['Option1', 'Option2']),
         )
+        @click.option(
+            '--numeric-choice',
+            metavar='<choice>',
+            help='A sample option with numeric choices',
+            type=click.Choice([1, 2, 3]),
+        )
         @click.argument('ARG', envvar='ARG')
         def foobar(bar):
             """A sample command."""
@@ -86,6 +94,12 @@ class CommandTestCase(unittest.TestCase):
 
             :options: Option1 | Option2
 
+        .. option:: --numeric-choice <choice>
+
+            A sample option with numeric choices
+
+            :options: 1 | 2 | 3
+
         .. rubric:: Arguments
 
         .. option:: ARG
@@ -252,6 +266,72 @@ class CommandTestCase(unittest.TestCase):
             '\n'.join(output),
         )
 
+    def test_ansi_escape_sequences(self):
+        """Validate that ANSI escape sequences are stripped."""
+
+        @click.command(epilog='\033[31mA sample epilog.\033[0m')
+        @click.option(
+            '--name',
+            help='Name to say \033[94mhello\033[0m to.',
+            required=True,
+            type=str,
+        )
+        @click.option(
+            '--choice',
+            help='A sample option with choices',
+            type=click.Choice(['\033[94mOption1\033[0m', '\033[94mOption2\033[0m']),
+        )
+        @click.option(
+            '--param',
+            default=lambda: None,
+            show_default='Something computed at \033[94mruntime\033[0m',
+        )
+        def foobar():
+            """A sample command with **sparkles**.
+
+            We've got \033[31mred text\033[0m, \033[104mblue backgrounds\033[0m, a
+            dash of \033[1mbold\033[0m and even some \033[4munderlined words\033[0m.
+            """
+            pass
+
+        ctx = click.Context(foobar, info_name='foobar')
+        output = list(ext._format_command(ctx, nested='short'))
+
+        self.assertEqual(
+            textwrap.dedent(
+                """
+        A sample command with **sparkles**.
+
+        We've got red text, blue backgrounds, a
+        dash of bold and even some underlined words.
+
+        .. program:: foobar
+        .. code-block:: shell
+
+            foobar [OPTIONS]
+
+        .. rubric:: Options
+
+        .. option:: --name <name>
+
+            **Required** Name to say hello to.
+
+        .. option:: --choice <choice>
+
+            A sample option with choices
+
+            :options: Option1 | Option2
+
+        .. option:: --param <param>
+
+            :default: Something computed at runtime
+
+        A sample epilog.
+        """
+            ).lstrip(),
+            '\n'.join(output),
+        )
+
 
 class GroupTestCase(unittest.TestCase):
     """Validate basic ``click.Group`` instances."""
@@ -697,8 +777,7 @@ class CommandCollectionTestCase(unittest.TestCase):
             """A world command."""
 
         cli = click.CommandCollection(
-            name='cli', sources=[grp1, grp2],
-            help='A simple CommandCollection.'
+            name='cli', sources=[grp1, grp2], help='A simple CommandCollection.'
         )
         ctx = click.Context(cli, info_name='cli')
         output = list(ext._format_command(ctx, nested='full'))
